WebDownloader is a Python package using Selenium to download web content. It is easy to use. 

Just start with this installation command:

    > pip install web-downloader

Then run the script:

    > import web_downloader.process_url as url
    > url.process_url('https://www.nba.com')

It will create a database called **web_downloader.db** in the script directory. Then it will download the specified url page and parse all its links within the page. Feel free to change it and play around with it.

Thanks a lot for your time and God bless you.

> Written with [StackEdit](https://stackedit.io/).
